--- pdnssec.cc.orig	2011-06-15 17:13:31.640455393 +1200
+++ pdnssec.cc	2011-06-15 17:49:26.834082252 +1200
@@ -467,8 +467,8 @@
     cerr<<"add-zone-key ZONE [zsk|ksk]     Add a ZSK or KSK to a zone\n";
     cerr<<"  [bits] [rsasha1|rsasha256]    and specify algorithm & bits\n";
     cerr<<"check-zone ZONE                 Check a zone for correctness\n";
-    cerr<<"deactivate-zone-key             Dectivate the key with key id KEY-ID in ZONE\n";
-    cerr<<"disable-dnssec ZONE             Deactivate all keys and unset PRESIGNED\n";
+    cerr<<"deactivate-zone-key ZONE KEY-ID Deactivate the key with key id KEY-ID in ZONE\n";
+    cerr<<"disable-dnssec ZONE             Deactivate all keys and unset PRESIGNED in ZONE\n";
     cerr<<"export-zone-dnskey ZONE KEY-ID  Export to stdout the public DNSKEY described\n";
     cerr<<"export-zone-key ZONE KEY-ID     Export to stdout the private key described\n";
     cerr<<"hash-zone-record ZONE RNAME     Calculate the NSEC3 hash for RNAME in ZONE\n";
@@ -496,16 +496,16 @@
   reportAllTypes();
   DNSSECKeeper dk;
 
-  if(cmds[0] == "rectify-zone" || cmds[0] == "order-zone") {
+  if(cmds[0] == "rectify-zone") {
     if(cmds.size() != 2) {
-      cerr << "Error: "<<cmds[0]<<" takes exactly 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec rectify-zone ZONE"<<endl;
       return 0;
     }
     rectifyZone(dk, cmds[1]);
   }
   else if(cmds[0] == "check-zone") {
     if(cmds.size() != 2) {
-      cerr << "Error: "<<cmds[0]<<" takes exactly 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec check-zone ZONE"<<endl;
       return 0;
     }
     exit(checkZone(dk, cmds[1]));
@@ -521,15 +521,15 @@
   }
 #endif
   else if(cmds[0] == "test-speed") {
-    if(cmds.size() < 3) {
-      cerr << "Error: "<<cmds[0]<<" takes  2 or 3 parameters, zone numcores [signing-server]"<<endl;
+    if(cmds.size() < 2) {
+      cerr << "Syntax: pdnssec test-speed numcores [signing-server]"<<endl;
       return 0;
     }
     testSpeed(dk, cmds[1],  (cmds.size() > 3) ? cmds[3] : "", atoi(cmds[2].c_str()));
   }
   else if(cmds[0] == "verify-crypto") {
     if(cmds.size() != 2) {
-      cerr << "Error: "<<cmds[0]<<" takes exactly 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec verify-crypto FILE"<<endl;
       return 0;
     }
     verifyCrypto(cmds[1]);
@@ -537,7 +537,7 @@
 
   else if(cmds[0] == "show-zone") {
     if(cmds.size() != 2) {
-      cerr << "Error: "<<cmds[0]<<" takes exactly 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec show-zone ZONE"<<endl;
       return 0;
     }
     const string& zone=cmds[1];
@@ -545,23 +545,35 @@
   }
   else if(cmds[0] == "disable-dnssec") {
     if(cmds.size() != 2) {
-      cerr << "Error: "<<cmds[0]<<" takes exactly 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec disable-dnssec ZONE"<<endl;
       return 0;
     }
     const string& zone=cmds[1];
     disableDNSSECOnZone(dk, zone);
   }
   else if(cmds[0] == "activate-zone-key") {
+    if(cmds.size() != 3) {
+      cerr << "Syntax: pdnssec activate-zone-key ZONE KEY-ID"<<endl;
+      return 0;
+    }
     const string& zone=cmds[1];
     unsigned int id=atoi(cmds[2].c_str());
     dk.activateKey(zone, id);
   }
   else if(cmds[0] == "deactivate-zone-key") {
+    if(cmds.size() != 2) {
+      cerr << "Syntax: pdnssec deactivate-zone-key ZONE KEY-ID"<<endl;
+      return 0;
+    }
     const string& zone=cmds[1];
     unsigned int id=atoi(cmds[2].c_str());
     dk.deactivateKey(zone, id);
   }
   else if(cmds[0] == "add-zone-key") {
+    if(cmds.size() < 3 ) {
+      cerr << "Syntax: pdnssec add-zone-key ZONE [zsk|ksk] [bits] [rsasha1|rsasha256]"<<endl;
+      return 0;
+    }
     const string& zone=cmds[1];
     // need to get algorithm, bits & ksk or zsk from commandline
     bool keyOrZone=false;
@@ -598,7 +610,7 @@
   }
   else if(cmds[0] == "remove-zone-key") {
     if(cmds.size() < 3) {
-      cerr<<"Syntax: pdnssec remove-zone-key ZONE KEY-ID\n";
+      cerr<<"Syntax: pdnssec remove-zone-key ZONE KEY-ID";
       return 0;
     }
     const string& zone=cmds[1];
@@ -608,7 +620,7 @@
   
   else if(cmds[0] == "secure-zone") {
     if(cmds.size() < 2) {
-      cerr << "Error: "<<cmds[0]<<" takes at least 1 parameter"<<endl;
+      cerr << "Syntax: pdnssec secure-zone ZONE"<<endl;
       return 0;
     }
     vector<string> mustRectify;
@@ -625,6 +637,10 @@
       rectifyZone(dk, zone);
   }
   else if(cmds[0]=="set-nsec3") {
+    if(cmds.size() < 2) {
+      cerr<<"Syntax: pdnssec set-nsec3 ZONE 'params' [narrow]"<<endl;
+      return 0;
+    }
     string nsec3params =  cmds.size() > 2 ? cmds[2] : "1 1 1 ab";
     bool narrow = cmds.size() > 3 && cmds[3]=="narrow";
     NSEC3PARAMRecordContent ns3pr(nsec3params);
@@ -637,19 +653,21 @@
   }
   else if(cmds[0]=="set-presigned") {
     if(cmds.size() < 2) {
-      cerr<<"Wrong number of arguments, syntax: set-presigned DOMAIN"<<endl;
+      cerr<<"Syntax: pdnssec set-presigned ZONE"<<endl;
+      return 0; 
     }
     dk.setPresigned(cmds[1]);
   }
   else if(cmds[0]=="unset-presigned") {
-	if(cmds.size() < 2) {
-		cerr<<"Wrong number of arguments, syntax: unset-presigned DOMAIN"<<endl;
-	}
+    if(cmds.size() < 2) {
+      cerr<<"Syntax: pdnssec unset-presigned ZONE"<<endl;
+      return 0;	
+    }
     dk.unsetPresigned(cmds[1]);
   }
   else if(cmds[0]=="hash-zone-record") {
     if(cmds.size() < 3) {
-      cerr<<"Wrong number of arguments, syntax: hash-zone-record ZONE RECORD"<<endl;
+      cerr<<"Syntax: pdnssec hash-zone-record ZONE RNAME"<<endl;
       return 0;
     }
     string& zone=cmds[1];
@@ -667,12 +685,15 @@
     cout<<toLower(toBase32Hex(hashQNameWithSalt(ns3pr.d_iterations, ns3pr.d_salt, record)))<<endl;
   }
   else if(cmds[0]=="unset-nsec3") {
+    if(cmds.size() < 2) {
+      cerr<<"Syntax: pdnssec unset-nsec3 ZONE"<<endl;
+      exit(1);
+    }
     dk.unsetNSEC3PARAM(cmds[1]);
   }
   else if(cmds[0]=="export-zone-key") {
     if(cmds.size() < 3) {
-      cerr<<"Syntax: pdnssec export-zone-key zone-name id"<<endl;
-      cerr<<cmds.size()<<endl;
+      cerr<<"Syntax: pdnssec export-zone-key ZONE KEY-ID"<<endl;
       exit(1);
     }
 
@@ -683,7 +704,7 @@
   }  
   else if(cmds[0]=="import-zone-key-pem") {
     if(cmds.size() < 4) {
-      cerr<<"Syntax: pdnssec import-zone-key zone-name filename.pem algorithm [zsk|ksk]"<<endl;
+      cerr<<"Syntax: pdnssec import-zone-key ZONE FILE algorithm [zsk|ksk]"<<endl;
       exit(1);
     }
     string zone=cmds[1];
@@ -727,8 +748,8 @@
     
   }
   else if(cmds[0]=="import-zone-key") {
-    if(cmds.size() < 3) {
-      cerr<<"Syntax: pdnssec import-zone-key zone-name filename [zsk|ksk]"<<endl;
+    if(cmds.size() < 4) {
+      cerr<<"Syntax: pdnssec import-zone-key ZONE FILE [zsk|ksk]"<<endl;
       exit(1);
     }
     string zone=cmds[1];
@@ -761,7 +782,7 @@
   }
   else if(cmds[0]=="export-zone-dnskey") {
     if(cmds.size() < 3) {
-      cerr<<"Syntax: pdnssec export-zone-dnskey zone-name id"<<endl;
+      cerr<<"Syntax: pdnssec export-zone-dnskey ZONE KEY-ID"<<endl;
       exit(1);
     }
 
